"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var test_tools_1 = require("@fluentui-react-native/test-tools");
var renderer = tslib_1.__importStar(require("react-test-renderer"));
var useConst_1 = require("../useConst");
describe('useConst', function () {
    (0, test_tools_1.validateHookValueNotChanged)('returns the same value with value initializer', function () { return [(0, useConst_1.useConst)(Math.random())]; });
    (0, test_tools_1.validateHookValueNotChanged)('returns the same value with function initializer', function () { return [(0, useConst_1.useConst)(function () { return Math.random(); })]; });
    it('calls the function initializer only once', function () {
        var initializer = jest.fn(function () { return Math.random(); });
        var TestComponent = function () {
            var value = (0, useConst_1.useConst)(initializer);
            return React.createElement(React.Fragment, null, value);
        };
        var wrapper = renderer.create(React.createElement(TestComponent, null));
        var firstValue = wrapper.toJSON();
        // Re-render the component
        wrapper.update(React.createElement(TestComponent, null));
        // Text should be the same
        expect(wrapper.toJSON()).toBe(firstValue);
        // Function shouldn't have been called again
        expect(initializer).toHaveBeenCalledTimes(1);
    });
    it('works with a function initializer which returns undefined', function () {
        var initializer = jest.fn(function () { return undefined; });
        var TestComponent = function () {
            var value = (0, useConst_1.useConst)(initializer);
            return React.createElement(React.Fragment, null, value);
        };
        var wrapper = renderer.create(React.createElement(TestComponent, null));
        // Re-render the component
        wrapper.update(React.createElement(TestComponent, null));
        // Function shouldn't have been called again
        expect(initializer).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=useConst.test.js.map