"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var test_tools_1 = require("@fluentui-react-native/test-tools");
var renderer = tslib_1.__importStar(require("react-test-renderer"));
var useControllableValue_1 = require("../useControllableValue");
describe('useControllableValue', function () {
    it('respects controlled value', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = (0, useControllableValue_1.useControllableValue)(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        var wrapper1 = renderer.create(React.createElement(TestComponent, { value: true }));
        expect(resultValue).toBe(true);
        wrapper1.update(React.createElement(TestComponent, { value: false }));
        expect(resultValue).toBe(false);
        var wrapper2 = renderer.create(React.createElement(TestComponent, { value: false, defaultValue: true }));
        expect(resultValue).toBe(false);
        wrapper2.update(React.createElement(TestComponent, { value: true, defaultValue: true }));
        expect(resultValue).toBe(true);
    });
    it('uses the default value if no controlled value is provided', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = (0, useControllableValue_1.useControllableValue)(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        renderer.create(React.createElement(TestComponent, { defaultValue: true }));
        expect(resultValue).toBe(true);
    });
    it('does not change value when the default value changes', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = (0, useControllableValue_1.useControllableValue)(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        var wrapper = renderer.create(React.createElement(TestComponent, { defaultValue: true }));
        expect(resultValue).toBe(true);
        wrapper.update(React.createElement(TestComponent, { defaultValue: false }));
        expect(resultValue).toBe(true);
    });
    (0, test_tools_1.validateHookValueNotChanged)('returns the same setter callback', function () {
        var _a = (0, useControllableValue_1.useControllableValue)('hello', 'world'), setValue = _a[1];
        return [setValue];
    });
    (0, test_tools_1.validateHookValueNotChanged)('returns same setter callback even if param values change', function () {
        var _a = (0, useControllableValue_1.useControllableValue)('a', 'b', function () { return undefined; }), setValue = _a[1];
        return [setValue];
    }, function () {
        var _a = (0, useControllableValue_1.useControllableValue)('c', 'd', function () { return undefined; }), setValue = _a[1];
        return [setValue];
    });
});
//# sourceMappingURL=useControllableValue.test.js.map