import * as React from 'react';
import { validateHookValueNotChanged } from '@fluentui-react-native/test-tools';
import * as renderer from 'react-test-renderer';
import { useConst } from '../useConst';
describe('useConst', function () {
    validateHookValueNotChanged('returns the same value with value initializer', function () { return [useConst(Math.random())]; });
    validateHookValueNotChanged('returns the same value with function initializer', function () { return [useConst(function () { return Math.random(); })]; });
    it('calls the function initializer only once', function () {
        var initializer = jest.fn(function () { return Math.random(); });
        var TestComponent = function () {
            var value = useConst(initializer);
            return React.createElement(React.Fragment, null, value);
        };
        var wrapper = renderer.create(React.createElement(TestComponent, null));
        var firstValue = wrapper.toJSON();
        // Re-render the component
        wrapper.update(React.createElement(TestComponent, null));
        // Text should be the same
        expect(wrapper.toJSON()).toBe(firstValue);
        // Function shouldn't have been called again
        expect(initializer).toHaveBeenCalledTimes(1);
    });
    it('works with a function initializer which returns undefined', function () {
        var initializer = jest.fn(function () { return undefined; });
        var TestComponent = function () {
            var value = useConst(initializer);
            return React.createElement(React.Fragment, null, value);
        };
        var wrapper = renderer.create(React.createElement(TestComponent, null));
        // Re-render the component
        wrapper.update(React.createElement(TestComponent, null));
        // Function shouldn't have been called again
        expect(initializer).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=useConst.test.js.map